@@ -38,6 +38,16 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.mysql.mysql_pool", fromlist="MysqlPool")
                         # 执行用例
                         pool = await clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "dm":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.dm.dm_pool", fromlist="DmPool")
+                        # 执行用例
+                        pool = await clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "generic":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.generic.generic_pool", fromlist="GenericPool")
+                        # 执行用例
+                        pool = await clazz(conn_info).create_pool()
                     elif conn_info.dialect == "mongodb":
                         # 获取包中用例的函数引用
                         clazz = InitConnectionPool.getClass("lesscode.db.mongodb.mongodb_pool", fromlist="MongodbPool")
@@ -106,6 +116,16 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.mysql.mysql_pool", fromlist="MysqlPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "dm":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.dm.dm_pool", fromlist="DmPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "generic":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.generic.generic_pool", fromlist="GenericPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
                     elif conn_info.dialect == "mongodb":
                         # 获取包中用例的函数引用
                         clazz = InitConnectionPool.getClass("lesscode.db.mongodb.mongodb_pool", fromlist="MongodbPool")
